@@ -2,14 +2,13 @@
 #' 
 #' \code{sheet2tbl} wraps \code{sheet2text} to parse sheets to tables.
 #' 
-#' \code{sheetid} is zero based, so normally \code{sheetid=0} will download the first sheet. 
-#' However, deleted sheets do not relinquish their \code{sheetid}, so if you create two sheets, then delete the first one, there will be no sheet 0, and the new first sheet will be sheet 1.
+#' \code{sheetid} is the index of the sheet to be downloaded. If you use the direct sheet URL, rather than the share by link, this will automatically be extracted. 
+#' Otherwise, the first sheet will be downloaded by default.
 #' 
 #' If this function produces unexpected results, use a construction like \code{read.csv(text=google_sheet2text(url, format='csv'), stringsAsFactors=FALSE)} to parse manually, with your own options. 
 #' The Google sheet must have 'share by link' turned on.
 #' 
 #' @param url the google sheet url
-#' @param sheetid the (zero based) id of the sheet to download from. (Default \code{NULL}, downloads the first sheet)
 #' 
 #' @seealso \code{\link{gsheet2text}} to download as plain text
 #' @export
@@ -20,9 +19,12 @@
 #' url <- 'docs.google.com/spreadsheets/d/1I9mJsS5QnXF2TNNntTy-HrcdHmIF9wJ8ONYvEJTXSNo'
 #' a <- gsheet2tbl(url)
 #' 
-#' # Download the same sheet by id
-#' b <- gsheet2tbl(url, sheetid = 0)
+#' # Download the second sheet, using the direct url
+#' url <- 'docs.google.com/spreadsheets/d/1I9mJsS5QnXF2TNNntTy-HrcdHmIF9wJ8ONYvEJTXSNo#gid=850032961'
+#' b <- gsheet2tbl(url)
 #' 
-gsheet2tbl <- function(url, sheetid=NULL){
-  dplyr::tbl_df(read.csv(text=gsheet::gsheet2text(url, format='csv', sheetid=sheetid), stringsAsFactors=FALSE))
+gsheet2tbl <- function(url){
+  table <- utils::read.csv(text=gsheet2text(url, format='csv'), stringsAsFactors=FALSE)
+  class(table) <- c("tbl_df", "tbl", "data.frame")
+  return(table)
 }
\ No newline at end of file
